from cpl_core.database.context import DatabaseContextABC

from cpl_discord.service import DiscordBotServiceABC

from bot_core.abc.client_utils_service_abc import ClientUtilsServiceABC
from bot_data.abc.client_repository_abc import ClientRepositoryABC
from bot_data.abc.server_repository_abc import ServerRepositoryABC


class ClientUtilsService(ClientUtilsServiceABC):

    def __init__(
            self,
            bot: DiscordBotServiceABC,
            servers: ServerRepositoryABC,
            clients: ClientRepositoryABC,
            db: DatabaseContextABC
    ):
        ClientUtilsServiceABC.__init__(self)
        self._bot = bot
        self._servers = servers
        self._clients = clients
        self._db = db

    def received_command(self, guild_id: int):
        server = self._servers.get_server_by_discord_id(guild_id)
        client = self._clients.find_client_by_discord_id_and_server_id(self._bot.user.id, server.server_id)
        client.received_command_count += 1
        self._clients.update_client(client)
        self._db.save_changes()

    def moved_user(self, guild_id: int):
        server = self._servers.get_server_by_discord_id(guild_id)
        client = self._clients.find_client_by_discord_id_and_server_id(self._bot.user.id, server.server_id)
        client.moved_users_count += 1
        self._clients.update_client(client)
        self._db.save_changes()

    def get_client(self, dc_ic: int, guild_id: int):
        server = self._servers.get_server_by_discord_id(guild_id)
        client = self._clients.find_client_by_discord_id_and_server_id(self._bot.user.id, server.server_id)
        return client
